package com.aliyun.imp.flutter.liveroom.alicloud_impinteraction_liveroom;

import android.app.Activity;
import android.util.Log;
import android.widget.Toast;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.aliyun.roompaas.base.exposable.Callback;
import com.aliyun.roompaas.base.util.Utils;
import com.aliyun.standard.liveroom.lib.LivePrototype;

import java.lang.ref.Reference;
import java.lang.ref.WeakReference;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

/**
 * AlicloudImpinteractionLiveroomPlugin
 */
public class AlicloudImpinteractionLiveroomPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware {
    public static final String TAG = "LiveroomPlugin";
    private MethodChannel channel;

    private Reference<Activity> activityRef;
    private LivePrototype.InitParam initParam;

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "alicloud_impinteraction_liveroom");
        channel.setMethodCallHandler(this);
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
        Utils.clear(activityRef);
    }

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        if (call.method.equals("init")) {
            initParam = new LivePrototype.InitParam();
            initParam.userId = call.argument("userId");
            initParam.appId = call.argument("appId");
            initParam.appKey = call.argument("appKey4Android");
            initParam.serverHost = call.argument("serverHost");
            initParam.serverSecret = call.argument("serverSecret");
            init(initParam);
            result.success("Android init: ");
        } else if (call.method.equals("setUp")) {
            setUp(call.argument("liveId"), call.argument("role"));
            result.success("Android setUp: " + 80);
        } else {
            result.notImplemented();
        }
    }

    private void init(LivePrototype.InitParam param) {
        Log.i(TAG, "init: " + param);
        Activity activity = Utils.getRef(activityRef);
        if (Utils.isActivityInvalid(activity)) {
            Log.i(TAG, "end : invalid activity:" + activityRef);
            return;
        }

        LivePrototype.getInstance().init(activity, param, new Callback<Void>() {
            @Override
            public void onSuccess(Void data) {
                toast("INSTANCE.init onSuccess: " + data);
            }

            @Override
            public void onError(String errorMsg) {
                toast("INSTANCE.init onError: " + errorMsg);
            }
        });
    }

    private void setUp(@Nullable String liveId, @Nullable String role) {
        Activity activity = Utils.getRef(activityRef);
        if (Utils.isActivityInvalid(activity)) {
            Log.i(TAG, "end : invalid activity:" + activityRef);
            return;
        }

        LivePrototype.OpenLiveParam param = new LivePrototype.OpenLiveParam();
        param.nick = "用户" + initParam.userId;

        param.role = parseValidRole(role);
        param.liveId = liveId;

        LivePrototype.getInstance().setup(activity, param, new Callback<String>() {
            @Override
            public void onSuccess(String data) {
                toast("setUp onSuccess: " + data);
            }

            @Override
            public void onError(String errorMsg) {
                toast("setUp onError: " + errorMsg);
            }
        });
    }

    private LivePrototype.Role parseValidRole(String role) {
        return LivePrototype.Role.ANCHOR.value.equalsIgnoreCase(role) ? LivePrototype.Role.ANCHOR : LivePrototype.Role.AUDIENCE;
    }

    private void toast(String str) {
        Log.i(TAG, str);
        Activity activity = Utils.getRef(activityRef);
        if (Utils.isActivityInvalid(activity)) {
            Log.i(TAG, "end : invalid activity:" + activityRef);
            return;
        }

        Toast.makeText(activity, str, Toast.LENGTH_LONG).show();
    }

    @Override
    public void onAttachedToActivity(ActivityPluginBinding activityPluginBinding) {
        activityRef = activityPluginBinding != null ? new WeakReference<>(activityPluginBinding.getActivity()) : null;
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {

    }

    @Override
    public void onReattachedToActivityForConfigChanges(ActivityPluginBinding activityPluginBinding) {

    }

    @Override
    public void onDetachedFromActivity() {
        Utils.clear(activityRef);
    }
}
